# Changelog

All notable changes to soweak will be documented in this file.

## [1.0.0] - 2025-01-19

### Added

- Initial release of soweak library
- Comprehensive prompt security analysis based on OWASP Top 10 for LLM Applications 2025
- **Detectors:**
  - LLM01: Prompt Injection Detector
  - LLM02: Sensitive Information Disclosure Detector
  - LLM04: Data and Model Poisoning Detector
  - LLM05: Improper Output Handling Detector
  - LLM06: Excessive Agency Detector
  - LLM07: System Prompt Leakage Detector
  - LLM08: Vector and Embedding Weaknesses Detector
  - LLM09: Misinformation Detector
  - LLM10: Unbounded Consumption Detector
- Risk Scoring System
- CLI Tool
- Comprehensive documentation